@@ -111,9 +111,9 @@ class Sherlock:
         return self
 
     def setup_detrend(self, initial_smooth=True, initial_rms_mask=True, initial_rms_threshold=1.5,
-                      initial_rms_bin_hours=3, n_detrends=6, detrend_method="biweight", cores=1,
-                      auto_detrend_periodic_signals=False, auto_detrend_ratio=1/4, auto_detrend_method="biweight",
-                      user_prepare=None):
+                      initial_rms_bin_hours=3, n_detrends=6, detrend_method="biweight", detrend_wl_min=None,
+                      detrend_wl_max=None, cores=1, auto_detrend_periodic_signals=False, auto_detrend_ratio=1/4,
+                      auto_detrend_method="biweight", user_prepare=None):
         """
         Configures the values for the detrends steps.
         @param initial_smooth: whether to execute an initial local noise reduction before the light curve analysis
@@ -143,6 +143,8 @@ class Sherlock:
         self.initial_smooth = initial_smooth
         self.n_detrends = n_detrends
         self.detrend_method = detrend_method
+        self.detrend_wl_min = detrend_wl_min
+        self.detrend_wl_max = detrend_wl_max
         self.detrend_cores = cores
         self.auto_detrend_periodic_signals = auto_detrend_periodic_signals
         self.auto_detrend_ratio = auto_detrend_ratio
@@ -313,11 +315,15 @@ class Sherlock:
             logging.info('================================================')
             logging.info('SEARCH RUNS')
             logging.info('================================================')
+            lcs, wl = self.__detrend(time, flux, star_info)
+            lcs = np.concatenate(([flux], lcs), axis=0)
+            wl = np.concatenate(([0], wl), axis=0)
             while best_signal_score == 1 and id_run <= self.max_runs:
                 object_report = {}
                 logging.info("________________________________ run %s________________________________", id_run)
                 transit_results, signal_selection = \
-                    self.__analyse(object_info, time, flux, flux_err, star_info, id_run, transits_min_count, cadence)
+                    self.__analyse(object_info, time, lcs, flux_err, star_info, id_run, transits_min_count, cadence,
+                                   self.report[sherlock_id], wl)
                 best_signal_score = signal_selection.score
                 object_report["Object Id"] = mission_id
                 object_report["run"] = id_run
@@ -327,6 +333,7 @@ class Sherlock:
                 object_report["sde"] = transit_results[signal_selection.curve_index].sde
                 object_report["fap"] = transit_results[signal_selection.curve_index].fap
                 object_report["border_score"] = transit_results[signal_selection.curve_index].border_score
+                object_report["harmonic"] = transit_results[signal_selection.curve_index].harmonic
                 object_report["period"] = transit_results[signal_selection.curve_index].period
                 object_report["per_err"] = transit_results[signal_selection.curve_index].per_err
                 object_report["duration"] = transit_results[signal_selection.curve_index].duration * 60 * 24
@@ -338,14 +345,14 @@ class Sherlock:
                 object_report["transits"] = np.array(transit_results[signal_selection.curve_index]
                                                           .results.transit_times)[real_transit_args.flatten()]
                 object_report["transits"] = ','.join(map(str, object_report["transits"]))
-                object_report["sectors"] = ','.join(map(str, sectors))
+                object_report["sectors"] = ','.join(map(str, sectors)) if sectors is not None and len(sectors) > 0 else None
                 object_report["ffi"] = isinstance(object_info, MissionFfiIdObjectInfo) or \
                                        isinstance(object_info, MissionFfiCoordsObjectInfo)
 
                 object_report["oi"] = self.__find_matching_oi(object_info, object_report["period"])
                 if best_signal_score == 1:
                     logging.info('New best signal is good enough to keep searching. Going to the next run.')
-                    time, flux = self.__apply_mask_from_transit_results(time, flux, transit_results,
+                    time, lcs = self.__apply_mask_from_transit_results(time, lcs, transit_results,
                                                                         signal_selection.curve_index)
                     id_run += 1
                     if id_run > self.max_runs:
@@ -356,8 +363,8 @@ class Sherlock:
             self.__setup_object_report_logging(sherlock_id)
             object_dir = self.__init_object_dir(object_info.sherlock_id())
             logging.info("Listing most promising candidates for ID %s:", sherlock_id)
-            logging.info("%-12s%-8s%-10s%-10s%-8s%-8s%-8s%-8s%-10s%-14s%-14s%-25s%-10s%-18s%-20s", "Detrend no.", "Period",
-                         "Per_err", "Duration", "T0", "Depth", "SNR", "SDE", "FAP", "Border_score", "Matching OI",
+            logging.info("%-12s%-8s%-10s%-10s%-8s%-8s%-8s%-8s%-10s%-14s%-14s%-12s%-25s%-10s%-18s%-20s", "Detrend no.", "Period",
+                         "Per_err", "Duration", "T0", "Depth", "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Harmonic",
                          "Planet radius (R_Earth)", "Rp/Rs", "Semi-major axis", "Habitability Zone")
             if sherlock_id in self.report:
                 candidates_df = pandas.DataFrame(columns=['curve', 'period', 'per_err', 'duration', 't0', 'depth',
@@ -374,11 +381,11 @@ class Sherlock:
                         report['rp_rs'] = np.nan
                     else:
                         report['rad_p'] = star_info.radius * math.sqrt(report["depth"] / 1000) / 0.0091577
-                    logging.info("%-12s%-8.4f%-10.5f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-10.6f%-14.2f%-14s%-25.5f%-10.5f%-18.5f%-20s",
+                    logging.info("%-12s%-8.4f%-10.5f%-10.2f%-8.2f%-8.3f%-8.2f%-8.2f%-10.6f%-14.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s",
                                  report["curve"], report["period"], report["per_err"],
                                  report["duration"], report["t0"], report["depth"], report["snr"], report["sde"],
-                                 report["fap"], report["border_score"], report["oi"], report['rad_p'], report['rp_rs'],
-                                 a, habitability_zone)
+                                 report["fap"], report["border_score"], report["oi"], report["harmonic"],
+                                 report['rad_p'], report['rp_rs'], a, habitability_zone)
                     candidates_df = candidates_df.append(report, ignore_index=True)
                     i = i + 1
                 candidates_df.to_csv(object_dir + "candidates.csv", index=False)
@@ -543,14 +550,30 @@ class Sherlock:
         flux = lc.flux
         flux_err = lc.flux_err
         time = lc.time
-        transit_duration = wotan.t14(R_s=star_info.radius, M_s=star_info.mass, P=self.period_protec,
-                                     small_planet=True)  # we define the typical duration of a small planet in this star
-        if self.detrend_method == 'gp':
-            self.wl_min[sherlock_id] = 1
-            self.wl_max[sherlock_id] = 12
+
+        logging.info('================================================')
+        logging.info("Window length / Kernel size")
+        if self.detrend_wl_min is not None and self.detrend_wl_max is not None:
+            logging.info("Using user input WL / KS")
+            if self.detrend_method == 'gp':
+                self.wl_min[sherlock_id] = self.detrend_wl_min
+                self.wl_max[sherlock_id] = self.detrend_wl_max
+            else:
+                self.wl_min[sherlock_id] = self.detrend_wl_min
+                self.wl_max[sherlock_id] = self.detrend_wl_max
         else:
-            self.wl_min[sherlock_id] = 3 * transit_duration  # minimum transit duration
-            self.wl_max[sherlock_id] = 20 * transit_duration  # maximum transit duration
+            logging.info("Using transit duration based WL or fixed KS")
+            transit_duration = wotan.t14(R_s=star_info.radius, M_s=star_info.mass, P=self.period_protec,
+                                         small_planet=True)  # we define the typical duration of a small planet in this star
+            if self.detrend_method == 'gp':
+                self.wl_min[sherlock_id] = 1
+                self.wl_max[sherlock_id] = 12
+            else:
+                self.wl_min[sherlock_id] = 3 * transit_duration  # minimum transit duration
+                self.wl_max[sherlock_id] = 20 * transit_duration  # maximum transit duration
+        logging.info("wl/ks_min: %.2f", self.wl_min[sherlock_id])
+        logging.info("wl/ks_min: %.2f", self.wl_max[sherlock_id])
+        logging.info('================================================')
         lc = lk.LightCurve(time=time, flux=flux, flux_err=flux_err)
         lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
         lc_df['#time'] = lc.time
@@ -650,6 +673,8 @@ class Sherlock:
         if is_short_cadence and self.initial_smooth:
             logging.info('Applying Savitzky-Golay filter')
             clean_flux = savgol_filter(clean_flux, 11, 3)
+            flux = np.convolve(flux, [0.025, 0.05, 0.1, 0.155, 0.34, 0.155, 0.1, 0.05, 0.025], "same")
+            flux = np.convolve(flux, [0.025, 0.05, 0.1, 0.155, 0.34, 0.155, 0.1, 0.05, 0.025], "same")
             #clean_flux = uniform_filter1d(clean_flux, 11)
             #clean_flux = self.flatten_bw(self.FlattenInput(clean_time, clean_flux, 0.02))[0]
         return clean_time, clean_flux, clean_flux_err
@@ -677,30 +702,27 @@ class Sherlock:
                                            method=self.auto_detrend_method, break_tolerance=0.5)
         return flatten_lc, lc_trend
 
-    def __analyse(self, object_info, time, lc, flux_err, star_info, id_run, transits_min_count, cadence):
-        detrend_lcs, wl = self.__detrend(time, lc, star_info, id_run)
-        lcs = np.concatenate(([lc], detrend_lcs), axis=0)
-        wl = np.concatenate(([0], wl), axis=0)
+    def __analyse(self, object_info, time, lcs, flux_err, star_info, id_run, transits_min_count, cadence, report, wl):
         logging.info('=================================')
         logging.info('SEARCH OF SIGNALS - Run %s', id_run)
         logging.info('=================================')
-        transit_results = self.__identify_signals(object_info, time, lcs, flux_err, star_info, transits_min_count, wl, id_run, cadence)
+        transit_results = self.__identify_signals(object_info, time, lcs, flux_err, star_info, transits_min_count, wl, id_run, cadence, report)
         signal_selection = self.signal_score_selectors[self.best_signal_algorithm]\
             .select(transit_results, self.snr_min, self.detrend_method, wl)
         logging.info(signal_selection.get_message())
         return transit_results, signal_selection
 
-    def __detrend(self, time, lc, star_info, id_run):
+    def __detrend(self, time, lc, star_info):
         wl_min = self.wl_min[star_info.object_id]
         wl_max = self.wl_max[star_info.object_id]
         bins = len(time) * 2 / self.bin_minutes
         bin_means, bin_edges, binnumber = stats.binned_statistic(time, lc, statistic='mean', bins=bins)
         logging.info('=================================')
-        logging.info('MODELS IN THE DETRENDING - Run ' + str(id_run))
+        logging.info('MODELS IN THE DETRENDING')
         logging.info('=================================')
         logging.info("%-25s%-17s%-15s%-11s%-15s", "light_curve", "Detrend_method", "win/ker_size", "RMS (ppm)",
                      "RMS_10min (ppm)")
-        logging.info("%-25s%-17s%-15s%-11.2f%-15.2f", "PDCSAP_FLUX_" + str(id_run), "---", "---", np.std(lc) * 1e6,
+        logging.info("%-25s%-17s%-15s%-11.2f%-15.2f", "PDCSAP_FLUX", "---", "---", np.std(lc) * 1e6,
                      np.std(bin_means[~np.isnan(bin_means)]) * 1e6)
         wl_step = (wl_max - wl_min) / self.n_detrends
         wl = np.arange(wl_min, wl_max, wl_step)  # we define all the posibles window_length that we apply
@@ -745,38 +767,40 @@ class Sherlock:
             plot_axs.plot(time, lc_trend, linewidth=1, color='orange', alpha=1.0)
             i = i + 1
 
-        plot_dir = self.__init_object_run_dir(star_info.object_id, id_run)
-        plt.savefig(plot_dir + 'Detrends_' + 'run_' + str(id_run) + '_' + str(star_info.object_id) + '.png', dpi=200)
+        plot_dir = self.__init_object_dir(star_info.object_id)
+        plt.savefig(plot_dir + 'Detrends_' + str(star_info.object_id) + '.png', dpi=200)
         fig.clf()
         plt.close(fig)
         return final_lcs, wl
 
-    def __identify_signals(self, object_info, time, lcs, flux_err, star_info, transits_min_count, wl, id_run, cadence):
+    def __identify_signals(self, object_info, time, lcs, flux_err, star_info, transits_min_count, wl, id_run, cadence, report):
         detrend_logging_customs = 'ker_size' if self.detrend_method == 'gp' else "win_size"
-        logging.info("%-12s%-10s%-10s%-8s%-18s%-14s%-14s%-12s%-12s%-14s%-16s%-14s%-25s%-10s%-18s%-20s",
+        logging.info("%-12s%-10s%-10s%-8s%-18s%-14s%-14s%-12s%-12s%-14s%-16s%-14s%-12s%-25s%-10s%-18s%-20s",
                      detrend_logging_customs, "Period", "Per_err", "N.Tran", "Mean Depth (ppt)", "T. dur (min)", "T0",
-                     "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Planet radius (R_Earth)", "Rp/Rs",
+                     "SNR", "SDE", "FAP", "Border_score", "Matching OI", "Harmonic", "Planet radius (R_Earth)", "Rp/Rs",
                      "Semi-major axis", "Habitability Zone")
         transit_results = {}
         object_dir = self.__init_object_dir(object_info.sherlock_id())
+        run_dir = self.__init_object_run_dir(object_info.sherlock_id(), id_run)
         lc_df = pandas.DataFrame(columns=['#time', 'flux', 'flux_err'])
         args = np.argwhere(~np.isnan(lcs[0])).flatten()
         lc_df['#time'] = time[args]
         lc_df['flux'] = lcs[0][args]
         lc_df['flux_err'] = flux_err[args]
-        lc_df.to_csv(object_dir + str(id_run) + "/lc_0.csv", index=False)
-        transit_result = self.__adjust_transit(time, lcs[0], star_info, transits_min_count)
+        lc_df.to_csv(run_dir + "/lc_0.csv", index=False)
+        transit_result = self.__adjust_transit(time, lcs[0], star_info, transits_min_count, transit_results, report, cadence)
         transit_results[0] = transit_result
         r_planet = self.__calculate_planet_radius(star_info, transit_result.depth)
         rp_rs = transit_result.results.rp_rs
         a, habitability_zone = self.habitability_calculator \
             .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
         oi = self.__find_matching_oi(object_info, transit_result.period)
-        logging.info('%-12s%-10.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-25.5f%-10.5f%-18.5f%-20s',
+        logging.info('%-12s%-10.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                      "PDCSAP_FLUX", transit_result.period,
                      transit_result.per_err, transit_result.count, transit_result.depth,
                      transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
-                     transit_result.fap, transit_result.border_score, oi, r_planet, rp_rs, a, habitability_zone)
+                     transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
+                     habitability_zone)
         plot_title = 'Run ' + str(id_run) + 'PDCSAP_FLUX # P=' + \
                      format(transit_result.period, '.2f') + 'd # T0=' + format(transit_result.t0, '.2f') + \
                      ' # Depth=' + format(transit_result.depth, '.4f') + ' # Dur=' + \
@@ -792,19 +816,20 @@ class Sherlock:
             lc_df['#time'] = time[args]
             lc_df['flux'] = lcs[i][args]
             lc_df['flux_err'] = flux_err[args]
-            lc_df.to_csv(object_dir + str(id_run) + "/lc_" + str(i) + ".csv", index=False)
-            transit_result = self.__adjust_transit(time, lcs[i], star_info, transits_min_count)
+            lc_df.to_csv(run_dir + "/lc_" + str(i) + ".csv", index=False)
+            transit_result = self.__adjust_transit(time, lcs[i], star_info, transits_min_count, transit_results, report, cadence)
             transit_results[i] = transit_result
             r_planet = self.__calculate_planet_radius(star_info, transit_result.depth)
             rp_rs = transit_result.results.rp_rs
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
             oi = self.__find_matching_oi(object_info, transit_result.period)
-            logging.info('%-12.4f%-10.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-25.5f%-10.5f%-18.5f%-20s',
+            logging.info('%-12.4f%-10.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-14s%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          wl[i], transit_result.period,
                      transit_result.per_err, transit_result.count, transit_result.depth,
                      transit_result.duration * 24 * 60, transit_result.t0, transit_result.snr, transit_result.sde,
-                     transit_result.fap, transit_result.border_score, oi, r_planet, rp_rs, a, habitability_zone)
+                     transit_result.fap, transit_result.border_score, oi, transit_result.harmonic, r_planet, rp_rs, a,
+                     habitability_zone)
             detrend_file_title_customs = 'ker_size' if self.detrend_method == 'gp' else 'win_size'
             detrend_file_name_customs = 'ks' if self.detrend_method == 'gp' else 'ws'
             title = 'Run ' + str(id_run) + '# ' + detrend_file_title_customs + ':' + str(format(wl[i], '.4f')) + \
@@ -830,12 +855,12 @@ class Sherlock:
             oi = ""
         return oi
 
-    def __adjust_transit(self, time, lc, star_info, transits_min_count):
+    def __adjust_transit(self, time, lc, star_info, transits_min_count, run_results, report, cadence):
         model = tls.transitleastsquares(time, lc)
         power_args = {"period_min": self.period_min, "period_max": self.period_max,
                       "n_transits_min": transits_min_count,
                       "show_progress_bar": False, "use_threads": self.run_cores,
-                      "T0_fit_margin": 0.05}
+                      "T0_fit_margin": 0.05, "oversampling_factor": 10}
         if star_info.ld_coefficients is not None:
             power_args["u"] = star_info.ld_coefficients
         if not star_info.radius_assumed:
@@ -855,7 +880,7 @@ class Sherlock:
             depth = results.transit_depths
         in_transit = tls.transit_mask(time, results.period, results.duration, results.T0)
         transit_count = results.distinct_transit_count
-        border_score = self.__compute_border_score(time, results, in_transit)
+        border_score = self.__compute_border_score(time, results, in_transit, cadence)
         # Recalculating duration because of tls issue https://github.com/hippke/tls/issues/83
         intransit_folded_model = np.where( results['model_folded_model'] < 1. )[0]
         if len(intransit_folded_model) > 0:
@@ -863,23 +888,27 @@ class Sherlock:
                                             - results['model_folded_phase'][intransit_folded_model[0]])
         else:
             duration = results['duration']
+        harmonic = self.__is_harmonic(results, run_results, report)
         return TransitResult(results, results.period, results.period_uncertainty, duration,
                              results.T0, depths, depth, transit_count, results.snr,
-                             results.SDE, results.FAP, border_score, in_transit)
+                             results.SDE, results.FAP, border_score, in_transit, harmonic)
 
     def __calculate_planet_radius(self, star_info, depth):
         return star_info.radius * math.sqrt(depth / 1000) / 0.0091577
 
-    def __compute_border_score(self, time, result, intransit):
+    def __compute_border_score(self, time, result, intransit, cadence):
+        shift_cadences = 60 / cadence
+        edge_limit_days = 0.05
         transit_depths = np.nan_to_num(result.transit_depths)
         transit_depths = np.zeros(1) if type(transit_depths) is not np.ndarray else transit_depths
         transit_depths = transit_depths[transit_depths > 0] if len(transit_depths) > 0 else []
+        # a=a[np.where([i for i, j in groupby(intransit)])]
         border_score = 0
         if len(transit_depths) > 0:
-            shifted_transit_points = shift(intransit, 30, cval=np.nan)
-            inverse_shifted_transit_points = shift(intransit, -30, cval=np.nan)
+            shifted_transit_points = shift(intransit, shift_cadences, cval=np.nan)
+            inverse_shifted_transit_points = shift(intransit, -shift_cadences, cval=np.nan)
             intransit_shifted = intransit | shifted_transit_points | inverse_shifted_transit_points
-            time_edge_indexes = np.where(abs(time[:-1] - time[1:]) > 0.05)[0]
+            time_edge_indexes = np.where(abs(time[:-1] - time[1:]) > edge_limit_days)[0]
             time_edge = np.full(len(time), False)
             time_edge[time_edge_indexes] = True
             time_edge[0] = True
@@ -887,7 +916,29 @@ class Sherlock:
             transits_in_edge = intransit_shifted & time_edge
             transits_in_edge_count = len(transits_in_edge[transits_in_edge])
             border_score = 1 - transits_in_edge_count / len(transit_depths)
-        return border_score
+        return border_score if border_score >= 0 else 0
+
+    def __is_harmonic(self, tls_results, run_results, report):
+        scales = [0.25, 0.5, 1, 2, 4]
+        if self.rotator_period is not None:
+            rotator_scale = round(tls_results.period / self.rotator_period, 2)
+            rotator_harmonic = np.array(np.argwhere((np.array(scales) > rotator_scale - 0.02) & (np.array(scales) < rotator_scale + 0.02))).flatten()
+            if len(rotator_harmonic) > 0:
+                return str(scales[rotator_harmonic[0]]) + "*source"
+        period_scales = [tls_results.period / round(item["period"], 2) for item in report]
+        for key, period_scale in enumerate(period_scales):
+            period_harmonic = np.array(np.argwhere((np.array(scales) > period_scale - 0.02) & (np.array(scales) < period_scale + 0.02))).flatten()
+            if len(period_harmonic) > 0:
+                period_harmonic = scales[period_harmonic[0]]
+                return str(period_harmonic) + "*SOI" + str(key + 1)
+        period_scales = [round(tls_results.period / run_results[key].period, 2) for key in run_results]
+        for key, period_scale in enumerate(period_scales):
+            period_harmonic = np.array(np.argwhere(
+                (np.array(scales) > period_scale - 0.02) & (np.array(scales) < period_scale + 0.02))).flatten()
+            if len(period_harmonic) > 0 and period_harmonic[0] != 2:
+                period_harmonic = scales[period_harmonic[0]]
+                return str(period_harmonic) + "*this(" + str(key) + ")"
+        return "-"
 
     def __trim_axs(self, axs, N):
         [axis.remove() for axis in axs.flat[N:]]
@@ -947,21 +998,25 @@ class Sherlock:
         fig.clf()
         plt.close(fig)
 
-    def __apply_mask_from_transit_results(self, time, flux, transit_results, best_signal_index):
+    def __apply_mask_from_transit_results(self, time, lcs, transit_results, best_signal_index):
         intransit = tls.transit_mask(time, transit_results[best_signal_index].period,
                                      2 * transit_results[best_signal_index].duration, transit_results[best_signal_index].t0)
         if self.mask_mode == 'subtract':
             model_flux, model_flux_edges, model_flux_binnumber = stats.binned_statistic(
                 transit_results[best_signal_index].results.model_lightcurve_time,
                 transit_results[best_signal_index].results.model_lightcurve_model, statistic='mean', bins=len(intransit))
-            flux[intransit] = flux[intransit] + np.full(len(flux[intransit]), 1) - model_flux[intransit]
-            flux[intransit] = np.full(len(flux[intransit]), 1)
+            for flux in lcs:
+                flux[intransit] = flux[intransit] + np.full(len(flux[intransit]), 1) - model_flux[intransit]
+                flux[intransit] = np.full(len(flux[intransit]), 1)
             clean_time = time
-            clean_flux = flux
+            clean_lcs = lcs
         else:
-            flux[intransit] = np.nan
-            clean_time, clean_flux = tls.cleaned_array(time, flux)
-        return clean_time, clean_flux
+            clean_lcs = []
+            for key, flux in enumerate(lcs):
+                flux[intransit] = np.nan
+                clean_time, clean_flux = tls.cleaned_array(time, flux)
+                clean_lcs.append(clean_flux)
+        return clean_time, np.array(clean_lcs)
 
     def run_multiprocessing(self, n_processors, func, func_input):
         with Pool(processes=n_processors) as pool:
